@@ -1,19 +1,17 @@
 from dataclasses import dataclass
-from typing import Callable, Optional, Tuple, Type, Union
+from typing import Any, Callable, Dict, Optional, Tuple, Type, Union
 
 
 @dataclass
 class FuncInfo:
     func: Callable
-    args: tuple
-    kwargs: dict
-    exception: Exception
-    owner_instance: Optional[object] = None
+    args: Tuple[Any, ...]
+    kwargs: Dict[str, Any]
+    exception: Optional[Exception] = None
 
 
 @dataclass
 class DecData:
     exceptions: Union[Tuple[Type[Exception], ...], Type[Exception]]
     exclude: bool
-    handler: Optional[Callable]
     func_info: FuncInfo
